package glzt.ui.video;



import java.util.ArrayList;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class VideoDevice {
	private String name;
	private String driver;
	private String model;
	private String version;
	private int currentParamIndex;
	private boolean supportMJPEG;
	private boolean supportYUV;
	private ArrayList<VideoParam> params;
		
	public final static String[] fps={"5","10","15","20","25","30"};
	public final static String[] fpsDesc={"5fps","10fps","15fps","20fps","25fps","30fps"};
	
	public VideoDevice(JSONObject video){
		
		try {
			setName(video.getString("device"));
			driver = video.getString("driver");
			setModel(video.getString("model"));
			version = video.getString("version");
			
			supportMJPEG = video.getBoolean("MJPEG");
			supportYUV = video.getBoolean("YUV");
			if(supportMJPEG){
				JSONArray mjpeg_support = video.getJSONArray("mjpeg_support");
				params = new ArrayList<VideoParam>();
				for(int i=0;i<mjpeg_support.length();i++){
					JSONObject tmp =  mjpeg_support.getJSONObject(i);
					VideoParam vp = new VideoParam(tmp);
					params.add(vp);
				}
			}
			if(!supportMJPEG && supportYUV){
				params = new ArrayList<VideoParam>();
				JSONArray yuv_support = video.getJSONArray("yuv_support");
				for(int i=0;i<yuv_support.length();i++){
					JSONObject tmp =  yuv_support.getJSONObject(i);
					VideoParam vp = new VideoParam(tmp);
					params.add(vp);
				}
			}
			
		} catch (JSONException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		currentParamIndex=-1;
	}
	
	public String getDescription(){
	   //return model + " " + driver+  " "+version ;
	   return getModel() + " " + driver;
	}
	
	public void setCurrentParamIndex(int index){
		currentParamIndex=index;
	}
	
    public VideoParam getCurrentParam(){
    	assert(currentParamIndex!=-1);
		return params.get(currentParamIndex);
	}

	public boolean equal(VideoDevice other){
		return this.getName().equalsIgnoreCase(other.getName());
	}
	
	public String description(){
		StringBuffer sb= new StringBuffer();
		sb.append("vedio test").append("\n");
		
		return sb.toString();
	}
	
	public String[] resolutions(){
		String[] a = new String[params.size()];
		for(int i=0;i<a.length;i++){
			a[i] = params.get(i).resolution();
		}
		return a;
	}
	
	public String resolutions2(){
		
		StringBuffer sb = new StringBuffer();
		for(int i=0;i<params.size();i++){
			sb.append(params.get(i).resolution()).append(",");
		}
		if(sb.length()>0)
			sb.setLength(sb.length()-1);
		return sb.toString();
	}	
	
	public boolean supportMJPEG(){
	    return 	supportMJPEG;
	}
	
	public boolean supportYUV(){
	    return 	supportYUV;
	}
	
	public ArrayList<VideoParam> getParams(){
		return params;
	}
	
	
	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}


	public String getModel() {
		return model;
	}

	public void setModel(String model) {
		this.model = model;
	}


	public class VideoParam{
		public String width;
		public String height;
		public String fps;
		
		public VideoParam(){
			
		}
		public VideoParam(String resolution,String fps){
			
			try {
				String[] s = resolution.split("x");
				width = s[0];
				height = s[1];
				this.fps=fps;
			} catch (Exception e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}
		
		public VideoParam(JSONObject json){
			try {
				width = json.getString("width");
				height = json.getString("height");
				
			} catch (JSONException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
			
			fps="15";
		}			
		
		public boolean equal(VideoParam v){
			return this.resolution().equalsIgnoreCase(v.resolution());
		}
		
		public String resolution(){
			return width+"x"+height;
		}
		
		public String toString(){
			if(width!=null)
			   return width+"x"+height+" ("+fps+"fps)";
			else
			   return "";
		}
		
		public boolean isValid(){
			return !(width==null || height == null ||  fps == null);
		}
	}
	
	
}

